document.addEventListener("DOMContentLoaded", () => {
    fetch("/config/pages_data.json")
        .then(response => response.json())
        .then(config => {
            document.querySelectorAll("[data-placeholder]").forEach(el => {
                const path = el.getAttribute("data-placeholder");
                const placeholderText = getConfigValue(config, path);
                if (placeholderText) {
                    el.textContent = placeholderText + (el.textContent ? " " + el.textContent : "");
                    el.removeAttribute("data-placeholder");
                }
            });

            document.querySelectorAll("[data-imgplaceholder]").forEach(el => {
                const path = el.getAttribute("data-imgplaceholder");
                const imgSrc = getConfigValue(config, path);
                if (imgSrc) {
                    el.innerHTML = `<img src="${imgSrc}" alt="">`;
                    el.removeAttribute("data-imgplaceholder");
                }
            });
        });
});

function getConfigValue(config, path) {
    const keys = path.split("/");
    let value = config;
    for (const key of keys) {
        if (value[key] === undefined) return null;
        value = value[key];
    }
    return parsePlaceholders(value, config);
}

function parsePlaceholders(text, config) {
    return text.replace(/{(text|img)&([^}]+)}/g, (match, type, path) => {
        const replacement = getConfigValue(config, path);
        if (replacement === null) return match;
        return type === "img" ? `<img src='${replacement}' alt=''>` : replacement;
    });
}
