<?php
session_start();
header('Content-Type: application/json');

// Путь к файлу базы данных
$bdPath = $_SERVER['DOCUMENT_ROOT'] . '/config/db.php';
require_once $bdPath;

// Проверка авторизации
if (!isset($_SESSION['user_id'])) {
    http_response_code(401);
    echo json_encode(['error' => 'Unauthorized']);
    exit();
}

// Проверка наличия всех необходимых параметров
if (!isset($_POST['amount'], $_POST['tokens'], $_POST['bonus_tokens'], $_POST['total_tokens'], $_POST['payment_token'])) {
    http_response_code(400);
    echo json_encode(['error' => 'Missing parameters']);
    exit();
}

try {
    // Форматирование чисел
    $amount = sprintf("%.8f", floatval($_POST['amount']));
    $tokens = sprintf("%.8f", floatval($_POST['tokens']));
    $bonus_tokens = sprintf("%.8f", floatval($_POST['bonus_tokens']));
    $total_tokens = sprintf("%.8f", floatval($_POST['total_tokens']));
    $user_id = $_SESSION['user_id'];
    $payment_token = $_POST['payment_token'];

    // Генерация хеша заказа
    function generateRandomOrderHash($length = 8) {
        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $charactersLength = strlen($characters);
        $orderHash = '';
        for ($i = 0; $i < $length; $i++) {
            $orderHash .= $characters[random_int(0, $charactersLength - 1)];
        }
        return $orderHash;
    }

    $order_hash = generateRandomOrderHash();

    // Подготовка и выполнение запроса
    $stmt = $conn->prepare("INSERT INTO orders (user_id, order_hash, amount, bonus_tokens, total_tokens, tokens, payment_token) VALUES (?, ?, ?, ?, ?, ?, ?)");
    $stmt->execute([$user_id, $order_hash, $amount, $bonus_tokens, $total_tokens, $tokens, $payment_token]);

    // Отправка успешного ответа
    echo json_encode(['success' => true, 'order' => $order_hash]);
    exit();

} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(['error' => 'Database error: ' . $e->getMessage()]);
    exit();
}
?>