<?php
session_start();
$bdPath = $_SERVER['DOCUMENT_ROOT'] . '/config/db.php';

require_once $bdPath;

$user_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;

if (!$user_id) {
    http_response_code(401);
    echo 'User not authenticated';
    exit();
}

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    $stmt = $conn->prepare('SELECT fullname, email, phone FROM main WHERE id = :user_id');
    $stmt->execute(['user_id' => $user_id]);
    $result = $stmt->fetch();

    if ($result) {
        echo json_encode([
            'fullname' => $result['fullname'],
            'email' => $result['email'],
            'phone' => $result['phone']
        ]);
    } else {
        echo json_encode(['error' => 'User not found']);
    }
    exit();
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $fullname = isset($_POST['fullname']) ? $_POST['fullname'] : null;
    $email = isset($_POST['email']) ? $_POST['email'] : null;
    $phone = isset($_POST['phone']) ? $_POST['phone'] : null;
    $password = isset($_POST['password']) ? $_POST['password'] : null;
    $newpassword = isset($_POST['newpassword']) ? $_POST['newpassword'] : null;

    if (empty($password)) {
        echo json_encode(['error' => 'Password is required']);
        exit();
    }

    $stmt = $conn->prepare('SELECT password FROM users WHERE id = :user_id');
    $stmt->execute(['user_id' => $user_id]);
    $result = $stmt->fetch();

    if (!$result) {
        echo json_encode(['error' => 'User not found']);
        exit();
    }

    if (password_verify($password, $result['password'])) {
    
        $updateFields = [];
        $params = ['user_id' => $user_id];

        if ($fullname) {
            $updateFields[] = 'fullname = :fullname';
            $params['fullname'] = $fullname;
        }
        if ($email) {
            $updateFields[] = 'email = :email';
            $params['email'] = $email;
        }
        if ($phone) {
            $updateFields[] = 'phone = :phone';
            $params['phone'] = $phone;
        }
        if ($newpassword) {
            if (empty($newpassword)) {
                echo json_encode(['error' => 'New password cannot be empty']);
                exit();
            }
            $updateFields[] = 'password = :newpassword';
            $params['newpassword'] = password_hash($newpassword, PASSWORD_DEFAULT);
        }

        if (count($updateFields) > 0) {
            $sql = 'UPDATE users SET ' . implode(', ', $updateFields) . ' WHERE id = :user_id';
            $stmt = $conn->prepare($sql);
            $stmt->execute($params);

            echo json_encode(['success' => 'User data updated']);
        } else {
            echo json_encode(['error' => 'No data to update']);
        }
    } else {
        echo json_encode(['error' => 'Incorrect password']);
    }

    exit();
}
