<?php
session_start();

$bdPath = $_SERVER['DOCUMENT_ROOT'] . '/config/db.php';

require_once $bdPath;

header('Content-Type: application/json');

if ($_SERVER["REQUEST_METHOD"] === "POST") {
    $fullname = trim($_POST["name"] ?? '');
    $email = trim($_POST["email"] ?? '');
    $phone = trim($_POST["phone"] ?? '');
    $password = $_POST["password"] ?? '';
    $confirmPassword = $_POST["confirmPassword"] ?? '';

    $errors = [];

    if (empty($fullname)) $errors["fullname_empty"] = "Full Name is required";
    if (empty($email)) $errors["email_empty"] = "Email is required";
    if (empty($phone)) $errors["phone_empty"] = "Phone Number is required";
    if (empty($password)) $errors["password_empty"] = "Password is required";
    if (empty($confirmPassword)) $errors["confirmPassword_empty"] = "Please confirm your password";

    if (strlen($password) > 128) {
        $errors["password_error"] = "Password is too long (max 128 characters)";
    }

    if ($password !== $confirmPassword) {
        $errors["confirmPassword_error"] = "Passwords do not match";
    }

    // Проверка на существующий email
    $stmt = $conn->prepare("SELECT id FROM main WHERE email = ?");
    $stmt->execute([$email]);
    if ($stmt->fetch()) {
        $errors["email_error"] = "Email is already taken";
    }

    if (!empty($errors)) {
        echo json_encode($errors);
        exit;
    }

    $hashedPassword = password_hash($password, PASSWORD_DEFAULT);

    try {
        $stmt = $conn->prepare("INSERT INTO main (email, balance, fullname, phone, password) VALUES (?, ?, ?, ?, ?)");
        $stmt->execute([$email, 0, $fullname, $phone, $hashedPassword]);

        $userId = $conn->lastInsertId();

        $_SESSION['user_id'] = $userId;

        echo json_encode(["success" => true]);
    } catch (PDOException $e) {
        error_log("Registration error: " . $e->getMessage());
        echo json_encode(["error" => $e->getMessage()]);
    }
}
